@@ -135,17 +135,6 @@
 #' sgdf <- SpatialGridDataFrame(sg, data.frame(val = 1:12))
 #' geojson_write(sgdf)
 #'
-#' # From SpatialRings
-#' library(rgeos)
-#' r1 <- Ring(cbind(x = c(1, 1, 2, 2, 1), y = c(1, 2, 2, 1, 1)), ID = "1")
-#' r2 <- Ring(cbind(x = c(1, 1, 2, 2, 1), y = c(1, 2, 2, 1, 1)), ID = "2")
-#' r1r2 <- SpatialRings(list(r1, r2))
-#' geojson_write(r1r2)
-#'
-#' # From SpatialRingsDataFrame
-#' dat <- data.frame(id = c(1, 2), value = 3:4)
-#' r1r2df <- SpatialRingsDataFrame(r1r2, data = dat)
-#' geojson_write(r1r2df)
 #'
 #' # From SpatialPixels
 #' library("sp")
@@ -160,14 +149,6 @@
 #' )
 #' geojson_write(pixelsdf)
 #'
-#' # From SpatialCollections
-#' library("sp")
-#' poly1 <- Polygons(list(Polygon(cbind(c(-100, -90, -85, -100), c(40, 50, 45, 40)))), "1")
-#' poly2 <- Polygons(list(Polygon(cbind(c(-90, -80, -75, -90), c(30, 40, 35, 30)))), "2")
-#' poly <- SpatialPolygons(list(poly1, poly2), 1:2)
-#' coordinates(us_cities) <- ~ long + lat
-#' dat <- SpatialCollections(points = us_cities, polygons = poly)
-#' geojson_write(dat)
 #'
 #' # From sf classes:
 #' if (require(sf)) {
@@ -309,67 +290,6 @@ geojson_write.SpatialPixelsDataFrame <- function(input, lat = NULL, lon = NULL,
   return(geo_file(file, "SpatialPixelsDataFrame"))
 }
 
-## spatial classes from rgeos -----------------
-#' @export
-geojson_write.SpatialRings <- function(input, lat = NULL, lon = NULL, geometry = "point",
-                                       group = NULL, file = "myfile.geojson",
-                                       overwrite = TRUE, precision = NULL,
-                                       convert_wgs84 = FALSE, crs = NULL, ...) {
-  write_geojson(as(input, "SpatialPolygonsDataFrame"), file,
-    precision = precision,
-    convert_wgs84 = convert_wgs84, crs = crs, ...
-  )
-  return(geo_file(file, "SpatialRings"))
-}
-
-#' @export
-geojson_write.SpatialRingsDataFrame <- function(input, lat = NULL, lon = NULL, geometry = "point",
-                                                group = NULL, file = "myfile.geojson",
-                                                overwrite = TRUE, precision = NULL,
-                                                convert_wgs84 = FALSE, crs = NULL, ...) {
-  write_geojson(as(input, "SpatialPolygonsDataFrame"), file,
-    precision = precision,
-    convert_wgs84 = convert_wgs84, crs = crs, ...
-  )
-  return(geo_file(file, "SpatialRingsDataFrame"))
-}
-
-#' @export
-geojson_write.SpatialCollections <- function(input, lat = NULL, lon = NULL,
-                                             geometry = "point",
-                                             group = NULL, file = "myfile.geojson",
-                                             overwrite = TRUE, precision = NULL,
-                                             convert_wgs84 = FALSE, crs = NULL, ...) {
-  ptfile <- iter_spatialcoll(input@pointobj, file,
-    precision = precision,
-    convert_wgs84 = convert_wgs84, crs = crs, ...
-  )
-  lfile <- iter_spatialcoll(input@lineobj, file,
-    precision = precision,
-    convert_wgs84 = convert_wgs84, crs = crs, ...
-  )
-  rfile <- iter_spatialcoll(input@ringobj, file,
-    precision = precision,
-    convert_wgs84 = convert_wgs84, crs = crs, ...
-  )
-  pyfile <- iter_spatialcoll(input@polyobj, file,
-    precision = precision,
-    convert_wgs84 = convert_wgs84, crs = crs, ...
-  )
-  return(structure(list(ptfile, lfile, rfile, pyfile), class = "spatialcoll"))
-}
-
-iter_spatialcoll <- function(z, file, precision = NULL, convert_wgs84 = FALSE,
-                             crs = NULL, ...) {
-  wfile <- sprintf("%s/%s_%s", dirname(file), class(z)[1], basename(file))
-  if (!is.null(z)) {
-    geojson_write(z,
-      file = wfile, precision = precision,
-      convert_wgs84 = convert_wgs84, crs = crs, ...
-    )
-  }
-}
-
 ## sf classes -----------------------------------------------------------------
 #' @export
 geojson_write.sf <- function(input, lat = NULL, lon = NULL, geometry = "point",
